package com.utic.center.utic.stat.server.dao.repository;

import com.utic.center.common.annotation.SqlOperation;
import com.utic.center.utic.stat.server.dao.mapper.UticStat05MinStatMapper;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Repository;

@Repository
@RequiredArgsConstructor
public class UticStat05MinStatRepository {

    private final UticStat05MinStatMapper mapper;

    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "CENTER_LOG", param = "regDate", param2 = "STAT_LOCAL")
    public int insertCenterLog(String regDate) {
        return this.mapper.insertCenterLog(regDate);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "STAT_TRAFFIC_LOG", param = "regDate", param2 = "TRAFFIC_CENTER_HIST")
    public int insertStatTrafficLog(String regDate) {
        return this.mapper.insertStatTrafficLog(regDate);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "FILTER_LOG", param = "regDate", param2 = "STAT_LOCAL, LINK_FILTER")
    public int insertFilterLog(String regDate, String codeValue0, String codeValue1, String codeValue2, String codeValue3, String codeValue4) {
        return this.mapper.insertFilterLog(regDate, codeValue0, codeValue1, codeValue2, codeValue3, codeValue4);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "LINK_FILTER_LOG", param = "STAT_LOCAL, LINK_FILTER")
    public int insertLinkFilterLog(String codeValue4) {
        return this.mapper.insertLinkFilterLog(codeValue4);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "STAT_5MIN_CENTER", param = "regDate", param2 = "STAT_LOCAL, LINK_FILTER")
    public int insertStat5MinCenter(String regDate, String codeValue4) {
        return this.mapper.insertStat5MinCenter(regDate, codeValue4);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "STAT_FILTER_LOG", param = "regDate", param2 = "STAT_LOCAL, STAT_5MIN_CENTER")
    public int insertStatFilterLog(String regDate) {
        return this.mapper.insertStatFilterLog(regDate);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "STAT_5MIN_CENTER", param = "linkLevel", param2 = "STAT_5MIN_CENTER")
    public int insertStat5MinCenterLevel(String linkLevel, String regDate) {
        return this.mapper.insertStat5MinCenterLevel(linkLevel, regDate);
    }
    @SqlOperation(type = SqlOperation.SqlType.UPDATE, table = "STAT_5MIN_CENTER", param = "regDate", param2 = "TRAVEL_TIME")
    public int updateStat5MinCenterTravelTime(String regDate) {
        return this.mapper.updateStat5MinCenterTravelTime(regDate);
    }

    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "STAT_5MIN_LOC", param = "STAT_LOCAL, LINK_FILTER, REV_TYPE = 'U'")
    public int insertStat5MinLoc(String regDate, String codeValue4) {
        return this.mapper.insertStat5MinLoc(regDate, codeValue4);
    }
    @SqlOperation(type = SqlOperation.SqlType.INSERT, table = "STAT_5MIN_LOC", param = "linkLevel", param2 = "STAT_5MIN_LOC")
    public int insertStat5MinLocLevel(String linkLevel, String regDate) {
        return this.mapper.insertStat5MinLocLevel(linkLevel, regDate);
    }
    @SqlOperation(type = SqlOperation.SqlType.UPDATE, table = "STAT_5MIN_LOC", param = "TRAVEL_TIME")
    public int updateStat5MinLocTravelTime(String regDate) {
        return this.mapper.updateStat5MinLocTravelTime(regDate);
    }

}
